@@ -102,6 +102,9 @@ class Hamiltonian():
     def get_chern(h,**kwargs):
         return topology.chern(h,**kwargs)
 
+    def get_berry_curvature(h,**kwargs):
+        return topology.get_berry_curvature(h,**kwargs)
+
     def get_chi(self,**kwargs):
         from . import chi
         return chi.chiAB_trace(self,**kwargs)
@@ -117,8 +120,8 @@ class Hamiltonian():
     def set_multihopping(self,mh):
         """Set a multihopping as the Hamiltonian"""
         multicell.set_multihopping(self,mh)
-    def get_berry_curvature(self,**kwargs):
-        return topology.write_berry(self,**kwargs)
+#    def get_berry_curvature(self,**kwargs):
+#        return topology.write_berry(self,**kwargs)
     @get_docstring(spectrum.set_filling)
     def set_filling(self,filling,**kwargs):
         spectrum.set_filling(self,filling=filling,**kwargs)
@@ -469,6 +472,8 @@ class Hamiltonian():
         """
         from .peierls import add_peierls
         add_peierls(self,mag_field=mag_field,**kwargs)
+    def add_orbital_magnetic_field(self,*args,**kwargs):
+        self.add_peierls(*args,**kwargs)
     def add_inplane_bfield(self,**kwargs):
         """Add in-plane magnetic field"""
         from .peierls import add_inplane_bfield
