@@ -123,7 +123,7 @@ def write_surface_2d(h,energies=None,klist=None,delta=0.01,
       else: op = operator # assume a matrix
       db = -algebra.trace(gs*op).imag # bulk
       ds = -algebra.trace(sf*op).imag # surface
-      fo.write(str(k)+"   "+str(energy)+"   "+str(ds)+"   "+str(db)+"\n")
+      fo.write(str(k[0])+"   "+str(energy)+"   "+str(ds)+"   "+str(db)+"\n")
       fo.flush()
   fo.close()
 
@@ -148,6 +148,7 @@ def write_surface_3d(h,energies=None,klist=None,delta=0.01):
 
 
 def kdos_bands(h,use_kpm=False,kpath=None,scale=10.0,frand=None,
+                 P = None,
                  ewindow=4.0,ne=1000,delta=0.01,ntries=10,nk=100,
                  operator=None,energies=np.linspace(-3.0,3.0,200),
                  mode="ED",**kwargs):
@@ -176,11 +177,11 @@ def kdos_bands(h,use_kpm=False,kpath=None,scale=10.0,frand=None,
       print("Doing",k)
       hk = hkgen(k) # get Hamiltonian
       npol = int(scale/delta) # number of polynomials
-      (x,y) = kpm.pdos(hk,scale=scale,npol=npol,ne=ne,operator=operator,
+      (x,y) = kpm.pdos(hk,scale=scale,npol=npol,ne=ne,P=P,
+                   operator=operator,
                    ewindow=ewindow,ntries=ntries,x=energies) # compute
       return (x,y)
-  if kpath is None: 
-      kpath = klist.default(h.geometry,nk=nk) # default
+  kpath = h.geometry.get_kpath(kpath,nk=nk) # generate kpath
   ### Now compute and write in a file
   ik = 0
   out = parallel.pcall(pfun,kpath) # compute all
