@@ -5,11 +5,11 @@ from . import geometry
 
 
 def twisted_bilayer(n=7,ti=0.12,lambi=3.0,lamb=3.0,is_sparse=True,
-        g=None,has_spin=False,dl=3.0,**kwargs):
+        g=None,g0=None,has_spin=False,dl=3.0,**kwargs):
     """
     Return the Hamiltonian of twisted bilayer graphene
     """
-    if g is None: g = specialgeometry.twisted_bilayer(n,dz=dl,**kwargs)
+    if g is None: g = specialgeometry.twisted_bilayer(n,dz=dl,g=g0,**kwargs)
     mgenerator = specialhopping.twisted_matrix(ti=ti,
             lambi=lambi,lamb=lamb,dl=dl)
     h = g.get_hamiltonian(is_sparse=is_sparse,has_spin=has_spin,
@@ -89,11 +89,13 @@ def TaS2_SOC(**kwargs):
 
 
 
-def TMDC_MX2(soc=0.0,cdw=0.0,g=None,ts=[1.0],normalize=True):
+def TMDC_MX2(soc=0.0,cdw=0.0,g=None,ts=[1.0],
+              drcdw = np.array([0.,0.,0.]), # shift in the CDW profile
+              normalize=True):
     """Return the Hamiltonian of NbSe2"""
     if g is None: 
         g = geometry.triangular_lattice()  # triangular lattice
-        if cdw!=0.0: g = g.supercell(3)
+        if cdw!=0.0: g = g.get_supercell(3,store_primal=True)
 #    ts = [1.0,0.3,0.6]
     ts = np.array(ts)
 #    t = ts[0]/np.max(ts) # 1NN 
@@ -116,6 +118,7 @@ def TMDC_MX2(soc=0.0,cdw=0.0,g=None,ts=[1.0],normalize=True):
         f0 = f0.normalize()*cdw
         f0 = f0.set_average(0.)
         rc = np.mean(h.geometry.get_closest_position([.1,.1,0.],n=3),axis=0)
+        rc = rc - np.array(drcdw) # add the shift
         f = lambda r: f0(r-rc)
         h.geometry.write_profile(f)
         h.add_onsite(f)
@@ -150,6 +153,32 @@ def triangular_pi_flux(g=None,**kwargs):
 
 
 
+def excitonic_bilayer(gap=0.0,g=None,**kwargs):
+    """Return the Hamiltonian for a bilayer system for an excitonic system"""
+    from .geometry import get_geometry
+    g0 = get_geometry(g) # get the geometry
+    h0 = g0.get_hamiltonian(has_spin=False) # spinless
+    hv = h0.copy() # valence
+    hc = h0.copy() # conduction
+    fermiv = hv.get_fermi4filling(1.0,nk=40) # fermi for valence
+    fermic = hc.get_fermi4filling(0.0,nk=40) # fermi for conduction
+    gv = g0.copy() # valence geometry
+    gc = g0.copy() # conduction geometry
+    gv = gv + np.array([0.,0.,-1]) # valence
+    gc = gc + np.array([0.,0.,1]) # conduction
+    g = gv + gc # add geometries
+    def tij(r1,r2):
+      dr = r1 - r2
+      dr2 = dr.dot(dr)
+      if 0.99<dr2<1.01: return np.sign(r1[2])
+      return 0.0
+    h = g.get_hamiltonian(tij=tij,has_spin=False) # no spin
+    def fons(r):
+      if r[2]>0.0: return -fermiv - gap/2.
+      else: return fermiv + gap/2
+    h.add_onsite(fons)
+    return h
+
 
 
 
